# Platooning Simulator

This project is a small addition to Carla. It aims to provide a simple way to validate control strategies of autonomous vehicle platoons in highly detailed simulations. It has been developed by Aron Karakai at the University of Groningen (Groningen, The Netherlands), supervised by Prof. dr. ir. Bart Besselink (Bernoulli Institute for Mathematics, Computer Science and Artificial Intelligence, Groningen, The Netherlands). 
For questions, suggestions, or feature requests, please send an email to a.karakai [at] student.rug.nl.